/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.validator;



/**
 * オブジェクトの同値関係を検証しその結果を返す{@link ValidatorExpression}。
 * {@link ValidatorContext}に対して状態を変更する操作を行わない。
 * @author nakamura
 *
 */
public class EqualsValidator implements ValidatorExpression {
	private final Object object;
	
	/**
	 * コンストラクタ。
	 * @param object 比較元。
	 * @throws NullPointerException 引数が null の場合。
	 */
	public EqualsValidator(final Object object){
		object.getClass();
		this.object = object;
	}

	/**
	 * @throws NullPointerException 引数が null の場合。
	 */
	public boolean interpret(final ValidatorContext context) {
		return object.equals(context.getTmpValue());
	}

	public Object getObject() {
		return object;
	}
}
